Staged class final
A level, spawned, with somebody standing in it ready to be stepped.
Constructors
- Staged({required ActorSystem actors, required Player player, required GameSimulation sim})
-
const
Properties
- actors → ActorSystem
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- player → Player
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sim → GameSimulation
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited