entities property

EcsWorld entities
final

One entity world for everything that has moved onto components, so that one save covers the lot. Two would be a save covering half the game.

Implementation

final EcsWorld entities;