hitscan property
One ray-caster shared by the player's shots and the monsters', because there is one world and a second would be a second answer about it.
Implementation
final Hitscan hitscan;
One ray-caster shared by the player's shots and the monsters', because there is one world and a second would be a second answer about it.
final Hitscan hitscan;