SampleEntities class abstract final

What this game's own entity types are called in a document.

The format's own vocabulary is EntityTypes; these three are furniture, and they live beside the kinds that implement them.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

lamp → const String
torch → const String
window → const String